@@ -87,6 +87,7 @@ types_converter_dict = {
         "type": {
             "string": "long varchar(65000)",
             "uuid": "long varchar(65000)",
+            "double": "double precision",
             "uint8": "integer",
             "uint16": "integer",
             "uint32": "integer",
@@ -123,6 +124,14 @@ dialect_dict = {
     "exasol": "exa+pyodbc",
 }
 
+quotes_dict = {
+    "ch": "`",
+    "pg": '"',
+    "mysql": '"',
+    "vertica": '"',
+    "exasol": '"',
+}
+
 
 def update_column_type(column, from_db, to_db):
     """convert types between source and destination"""
@@ -207,28 +216,31 @@ def get_table_schema(table_name, meta):
 
 
 class FieldsConverter:
+    def __init__(self, sql_credentials, from_db, to_db, debug=True, tables=None):
+        """
 
-    def __init__(self, sql_credentials, from_db, to_db):
+        :param sql_credentials:
+        :param from_db:
+        :param to_db:
+        :param debug: show debug text
+        :param tables: converter only for list of tables. Will process more rapidly
+        """
+        self.tables = tables or []
         self.from_db = from_db
         self.to_db = to_db
+        self.debug = debug
         self.sql_credentials = sql_credentials
-        if self.to_db == "vertica":
-            self.quote_char = '"'
-        elif self.to_db == "exasol":
-            self.quote_char = '"'
-        else:
-            self.quote_char = "`"
 
         cred_from = self.sql_credentials[self.from_db]
 
-        if cred_from["type"] not in dialect_dict:
+        if self.from_db not in dialect_dict:
             raise ModuleNotFoundError(
                 "Dialect for {} type of database was'nt found, should be in list {}".format(
-                    cred_from["type"], list(dialect_dict.keys())
+                    self.from_db, list(dialect_dict.keys())
                 )
             )
         else:
-            dialect_from = dialect_dict[cred_from["type"]]
+            dialect_from = dialect_dict[self.from_db]
 
         uri_sql_alchemy_from = "{0}://{1}:{2}@{3}:{4}/{5}".format(
             dialect_from,
@@ -239,14 +251,14 @@ class FieldsConverter:
             cred_from["database"],
         )
         cred_to = self.sql_credentials[self.to_db]
-        if cred_to["type"] not in dialect_dict:
+        if self.to_db not in dialect_dict:
             raise ModuleNotFoundError(
                 "Dialect for {} type of database was'nt found, should be in list {}".format(
-                    cred_to["type"], list(dialect_dict.keys())
+                    self.to_db, list(dialect_dict.keys())
                 )
             )
         else:
-            dialect_to = dialect_dict[cred_to["type"]]
+            dialect_to = dialect_dict[self.to_db]
 
         uri_sql_alchemy_to = "{0}://{1}:{2}@{3}:{4}/{5}".format(
             dialect_to,
@@ -256,26 +268,52 @@ class FieldsConverter:
             cred_to["port"],
             cred_to["database"],
         )
-
+        self.quote_char = quotes_dict[self.to_db]
         engine_from = create_engine(uri_sql_alchemy_from)
         self.conn_from = engine_from.connect()
-        logging.info("connecting to {} successfull".format(self.from_db))
+        self.log("connecting to {} successfull".format(self.from_db))
         engine_to = create_engine(uri_sql_alchemy_to)
         self.conn_to = engine_to.connect()
-        logging.info("connecting to {} successfull".format(self.to_db))
+        self.log("connecting to {} successfull".format(self.to_db))
         if "schema" in cred_from:
             self.schema_from = cred_from["schema"]
-            self.meta_from = MetaData(
-                bind=engine_from, reflect=True, schema=self.schema_from
-            )
+            self.meta_from = MetaData(bind=engine_from, schema=self.schema_from)
         else:
-            self.meta_from = MetaData(bind=engine_from, reflect=True)
+            self.meta_from = MetaData(bind=engine_from)
+
         if "schema" in cred_to:
             self.schema_to = cred_to["schema"]
-            self.meta_to = MetaData(bind=engine_to, reflect=True, schema=self.schema_to)
+            self.meta_to = MetaData(bind=engine_to, schema=self.schema_to)
+        else:
+            self.meta_to = MetaData(bind=engine_to)
 
+        if len(self.tables) > 0:
+            self.meta_from.reflect(only=self.tables)
+            self.meta_to.reflect(only=self.tables)
+        else:
+            self.meta_from.reflect()
+            self.meta_to.reflect()
+
+
+    def log(self, text):
+        if self.debug:
+            logging.info(self.__str__ + ": " + text)
+
+    def check_if_table_availible(self, table):
+        if len(self.tables) > 0 and table not in self.tables:
+            raise ModuleNotFoundError(
+                "Table_name to convert {} should be in list{} or set tables param to defult".format(
+                    table, self.tables
+                )
+            )
+
+    @property
     def __str__(self):
-        return "FieldsConverter{}_{}".format(self.from_db, self.to_db)
+        return "FieldsConverter_{}_{}".format(self.from_db, self.to_db)
+
+    @property
+    def __repr__(self):
+        return "FieldsConverter_{}_{}".format(self.from_db, self.to_db)
 
     def __del__(self):
         self.conn_from.close()
@@ -307,7 +345,7 @@ class FieldsConverter:
 
         txt += ",".join(
             [
-                field + " " + str(fields[field])
+                self.quote_char + field + self.quote_char + " " + str(fields[field])
                 for field in fields
                 if field != "password"
             ]
@@ -333,17 +371,20 @@ class FieldsConverter:
         else:
             return [dict(zip(columns, r)) for r in rows]
 
-    def get_columns(self, table_name, db="mysql", type=None, table_from=True):
+    def get_columns(self, table_name, table_from=True):
+        """get column:type dict"""
+        self.check_if_table_availible(table_name)
         if table_from:
-            fields = self.get_table_scheme_mysql(table_name, self.meta_from)
+            fields = get_table_schema(table_name, self.meta_from)
         else:
-            fields = self.get_table_scheme_mysql(table_name, self.meta_to)
+            fields = get_table_schema(table_name, self.meta_to)
         columns = [f["column_name"] for f in fields]
         types = [f["data_type"] for f in fields]
         return dict(zip(columns, types))
 
     def create_ddl(self, table_name):
         sort_part = None
+        self.check_if_table_availible(table_name)
         fields = get_table_schema(table_name, self.meta_from)
         fields_new = {}
         for f in fields:
@@ -355,6 +396,7 @@ class FieldsConverter:
         )
 
     def drop_list_of_tables(self, tables):
+        """drop every fkn table in list"""
         for table in tables:
             sql = "drop table {schema}.{table} cascade ".format(
                 schema=self.schema_to, table=table
